const env = 'staging'; // "development", "staging" , "production"

const integrations = {
  dashboardSvcUrl: 'https://stg-dashboard-api.alt.technology/v1', // "http://localhost:8000/v1" , "https://api.da.apiz.io/v1"
  ideUrl: 'https://stg-dashboard.alt.technology/ide/index.html', // "http://localhost:8080"
  gtagId: 'G-47MC1MN85Z', // e.g. G-ABC123
  stripePublishableKey:
    'pk_test_51MJymAESVAjpZ7phhpxf7xaW1HIoImWDF7mFowSkAkz2Fhyw0zvziHBVET1CLXpUqEbhmHijvQA5kNTcLnZZtOyG00EjGQxk8E',
  walletConnectProjectId: '0de3ccbb3f93552d628e7514c6299b16',
  googleOauthClientId: '539302499667-f88unnof3hrl60cubfmr2q8ujf5jdjcq.apps.googleusercontent.com',
};

const ui = {
  gasLimitOverrides: {
    // key-values <fnName, gasOverrideFn>
    // e.g. claimRewards: (gasEstimate: BigNumber) => gasEstimate?.mul(150)?.div(100) --> use 150% of original estimate for "claimRewards" function
  },
  contractAliases: {
    // stakedErc20: {
    //   name: 'Wrapped Ether',
    //   symbol: 'WETH',
    // },
  },
  eigenlayerRestaking: {
    chainId: 5,
    strategyManagerAddress: '0x779d1b5315df083e3F9E94cB495983500bA8E907',
    restakingTokenBaseUrl: 'https://goerli.eigenlayer.xyz/token/',
    strategies: {
      '0x879944A8cB437a5f8061361f82A6d4EED59070b5': {
        tokenSymbol: 'rETH',
        tokenImgUrl: '/static/images/tokenIcons/rETH.png',
      },
      '0xB613E78E2068d7489bb66419fB1cfa11275d14da': {
        tokenSymbol: 'stETH',
        tokenImgUrl: '/static/images/tokenIcons/stETH.png',
      },
    },
  },
  oasysFLsPerAddress: {
    testnet: 1000,
    mainnet: 1,
  },
  enableMockApi: false,
};

// Wagmi chains to import. Uses rpc urls, token symbol, decimals, etc. from wagmi/chains.
// Overrides may be specified in the {} object
const defaultWagmiChains = {
  mainnet: {
    iconUrl: '/static/images/chainIcons/ethereum.svg',
    isPreferred: true,
  },
  sepolia: {
    iconUrl: '/static/images/chainIcons/ethereum.svg',
    isPreferred: true,
    rpcUrls: {
      default: {
        http: [
          'https://sepolia-geth.alt.technology',
          'https://eth-sepolia.g.alchemy.com/v2/demo',
          'https://ethereum-sepolia.blockpi.network/v1/rpc/public',
        ],
      },
      public: {
        http: [
          'https://sepolia-geth.alt.technology',
          'https://eth-sepolia.g.alchemy.com/v2/demo',
          'https://ethereum-sepolia.blockpi.network/v1/rpc/public',
        ],
      },
    },
  },
  goerli: {
    iconUrl: '/static/images/chainIcons/ethereum.svg',
  },
  arbitrum: {
    iconUrl: '/static/images/chainIcons/arbitrum.svg',
    isPreferred: true,
  },
  bscTestnet: {
    iconUrl: '/static/images/chainIcons/bsc.svg',
    isPreferred: true,
  },
  bsc: {
    iconUrl: '/static/images/chainIcons/bsc.svg',
    isPreferred: true,
  },
  polygon: {
    iconUrl: '/static/images/chainIcons/polygon.svg',
    isPreferred: true,
  },
  polygonMumbai: {
    iconUrl: '/static/images/chainIcons/polygon.svg',
    isPreferred: true,
  },
  klaytn: {
    rpcUrls: {
      default: {
        http: [
          'https://public-node-api.klaytnapi.com/v1/cypress',
          'https://klaytn.blockpi.network/v1/rpc/public',
        ],
      },
      public: {
        http: [
          'https://public-node-api.klaytnapi.com/v1/cypress',
          'https://klaytn.blockpi.network/v1/rpc/public',
        ],
      },
    },
    iconUrl: '/static/images/chainIcons/klaytn.webp',
    isPreferred: true,
  },
};

// Custom Chains in the format of Rainbowkit's exported Chain type, with a few other app specific vars such as faucetLink and isPreferred
const customChains = {
  multiSequencerTestnet: {
    id: 9997,
    network: 'AltLayer Multi Sequencer Testnet',
    name: 'AltLayer Multi Sequencer Testnet',
    nativeCurrency: {
      name: 'Ether',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://testnet-rollup-api.altlayer.io'],
        webSocket: ['wss://testnet-rollup-api-ws.altlayer.io'],
      },
      public: {
        http: ['https://testnet-rollup-api.altlayer.io'],
        webSocket: ['wss://testnet-rollup-api-ws.altlayer.io'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Explorer',
        url: 'https://testnet-rollup-explorer.altlayer.io',
      },
    },
    faucetLink: 'https://testnet-faucet.altlayer.io',
    bridgeLink: 'https://testnet-rollup-bridge.altlayer.io',
    testnet: true,
    iconUrl: '/static/images/chainIcons/altlayer.jpeg',
    isPreferred: true,
  },
  altBeacon: {
    id: 9993,
    name: 'AltLayer Beacon Chain',
    network: 'AltLayer Beacon Chain',
    nativeCurrency: {
      name: 'ALT',
      symbol: 'ALT',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://prdbc20230630beaconlayer-beacon.alt.technology'],
        webSocket: ['wss://prdbc20230630beaconlayer-beacon.alt.technology/ws'],
      },
      public: {
        http: ['https://prdbc20230630beaconlayer-beacon.alt.technology'],
        webSocket: ['wss://prdbc20230630beaconlayer-beacon.alt.technology/ws'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Explorer',
        url: 'https://prdbc20230630beaconlayer-beacon-explorer.alt.technology',
      },
    },
    faucetLink: 'https://beacon-faucet.alt.technology',
    iconUrl: '/static/images/chainIcons/altlayer.jpeg',
    testnet: true,
    preventRollup: true,
  },
  linea: {
    id: 59144,
    name: 'Linea Mainnet Alpha',
    network: 'Linea Mainnet Alpha',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://linea-mainnet.infura.io/v3'],
      },
      public: {
        http: ['https://linea-mainnet.infura.io/v3'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Linea Mainnet Explorer',
        url: 'https://explorer.linea.build',
      },
    },
    iconUrl: '/static/images/chainIcons/linea.png',
    isPreferred: true,
  },
  lineaTestnet: {
    id: 59140,
    name: 'Linea Testnet',
    network: 'Linea Testnet',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.goerli.linea.build'],
      },
      public: {
        http: ['https://rpc.goerli.linea.build'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Linea Testnet Explorer',
        url: 'https://explorer.goerli.linea.build',
      },
    },
    iconUrl: '/static/images/chainIcons/linea.png',
    faucetLink: 'https://faucet.goerli.linea.build',
    testnet: true,
    isPreferred: true,
  },
  mantleTestnet: {
    id: 5001,
    name: 'Mantle Testnet',
    network: 'Mantle Testnet',
    nativeCurrency: {
      name: 'BIT',
      symbol: 'BIT',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.testnet.mantle.xyz'],
      },
      public: {
        http: ['https://rpc.testnet.mantle.xyz'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Mantle Testnet Explorer',
        url: 'https://explorer.testnet.mantle.xyz',
      },
    },
    faucetLink: 'https://faucet.testnet.mantle.xyz/',
    iconUrl: '/static/images/chainIcons/mantle.png',
    testnet: true,
  },
  oasysMainnet: {
    id: 248,
    name: 'Oasys Mainnet',
    network: 'Oasys Mainnet',
    nativeCurrency: {
      name: 'OAS',
      symbol: 'OAS',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.mainnet.oasys.games', 'https://oasys.blockpi.network/v1/rpc/public'],
      },
      public: {
        http: ['https://rpc.mainnet.oasys.games', 'https://oasys.blockpi.network/v1/rpc/public'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Oasys Mainnet Explorer',
        url: 'https://scan.oasys.games/',
      },
    },
    iconUrl: '/static/images/chainIcons/oasys.png',
    isPreferred: true,
  },
  oasysTestnet: {
    id: 9372,
    name: 'Oasys Testnet',
    network: 'Oasys Testnet',
    nativeCurrency: {
      name: 'OAS',
      symbol: 'OAS',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.testnet.oasys.games'],
      },
      public: {
        http: ['https://rpc.testnet.oasys.games'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Oasys Testnet Explorer',
        url: 'https://scan.testnet.oasys.games/',
      },
    },
    faucetLink: 'https://faucet.testnet.oasys.games/',
    iconUrl: '/static/images/chainIcons/oasys.png',
    testnet: true,
    isPreferred: true,
  },
  arbitrumNova: {
    id: 42170,
    name: 'Arbitrum Nova',
    network: 'Arbitrum Nova',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://nova.arbitrum.io/rpc'],
      },
      public: {
        http: ['https://nova.arbitrum.io/rpc'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Arbitrum Nova Explorer',
        url: 'https://nova.arbiscan.io/',
      },
    },
    iconUrl: '/static/images/chainIcons/arbitrum.svg',
    isPreferred: true,
  },
  klaytnTestnet: {
    id: 1001,
    name: 'Klaytn Testnet Baobab',
    network: 'Klaytn Testnet Baobab',
    nativeCurrency: {
      name: 'KLAY',
      symbol: 'KLAY',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: [
          'https://public-node-api.klaytnapi.com/v1/baobab',
          'https://klaytn-baobab.blockpi.network/v1/rpc/public',
        ],
      },
      public: {
        http: [
          'https://public-node-api.klaytnapi.com/v1/baobab',
          'https://klaytn-baobab.blockpi.network/v1/rpc/public',
        ],
      },
    },
    blockExplorers: {
      default: {
        name: 'Baobab Klaytn Scope',
        url: 'https://baobab.klaytnscope.com/',
      },
    },
    isPreferred: true,
    iconUrl: '/static/images/chainIcons/klaytn.webp',
    testnet: true,
  },
  opBnbMainnet: {
    id: 204,
    name: 'opBNB Mainnet',
    network: 'opBNB Mainnet',
    nativeCurrency: {
      name: 'BNB',
      symbol: 'BNB',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://opbnb-mainnet-rpc.bnbchain.org'],
      },
      public: {
        http: ['https://opbnb-mainnet-rpc.bnbchain.org'],
      },
    },
    blockExplorers: {
      default: {
        name: 'opBNB Explorer',
        url: 'https://opbnbscan.com/',
      },
    },
    isPreferred: true,
    iconUrl: '/static/images/chainIcons/opbnb.ico',
  },
  opBnbTestnet: {
    id: 5611,
    name: 'opBNB Testnet',
    network: 'opBNB Testnet',
    nativeCurrency: {
      name: 'tBNB',
      symbol: 'tBNB',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://opbnb-testnet-rpc.bnbchain.org'],
      },
      public: {
        http: ['https://opbnb-testnet-rpc.bnbchain.org'],
      },
    },
    blockExplorers: {
      default: {
        name: 'opBNB Testnet Explorer',
        url: 'https://opbnb-testnet.bscscan.com/',
      },
    },
    isPreferred: true,
    iconUrl: '/static/images/chainIcons/opbnb.ico',
    testnet: true,
  },
  arbitrumSepolia: {
    id: 421614,
    name: 'Arbitrum Sepolia',
    network: 'Arbitrum Sepolia',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://sepolia-rollup.arbitrum.io/rpc'],
      },
      public: {
        http: ['https://sepolia-rollup.arbitrum.io/rpc'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Arbitrum Sepolia Rollup Explorer',
        url: 'https://sepolia-explorer.arbitrum.io/',
      },
    },
    isPreferred: true,
    iconUrl: '/static/images/chainIcons/arbitrum.svg',
    testnet: true,
  },
  tomoChainMainnet: {
    id: 88,
    name: 'TomoChain Mainnet',
    network: 'TomoChain Mainnet',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.tomochain.com'],
        webSocket: ['wss://ws.tomochain.com'],
      },
      public: {
        http: ['https://rpc.tomochain.com'],
        webSocket: ['wss://ws.tomochain.com'],
      },
    },
    blockExplorers: {
      default: {
        name: 'TomoScan Explorer',
        url: 'https://scan.tomochain.com/',
      },
    },
    iconUrl: '/static/images/chainIcons/tomoChain.png',
  },
  tomoChainTestnet: {
    id: 89,
    name: 'TomoChain Testnet',
    network: 'TomoChain Testnet',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.testnet.tomochain.com'],
        webSocket: ['wss://ws.testnet.tomochain.com'],
      },
      public: {
        http: ['https://rpc.testnet.tomochain.com'],
        webSocket: ['wss://ws.testnet.tomochain.com'],
      },
    },
    blockExplorers: {
      default: {
        name: 'TomoScan Testnet Explorer',
        url: 'https://scan.testnet.tomochain.com/',
      },
    },
    iconUrl: '/static/images/chainIcons/tomoChain.png',
    testnet: true,
  },
  astarTestnet: {
    id: 1261120,
    name: 'Astar zKatana Testnet',
    network: 'Astar zKatana Testnet',
    nativeCurrency: {
      name: 'ETH',
      symbol: 'ETH',
      decimals: 18,
    },
    rpcUrls: {
      default: {
        http: ['https://rpc.startale.com/zkatana'],
        webSocket: ['wss://ws.zkatana.gelato.digital'],
      },
      public: {
        http: ['https://rpc.startale.com/zkatana'],
        webSocket: ['wss://ws.zkatana.gelato.digital'],
      },
    },
    blockExplorers: {
      default: {
        name: 'Astar zKatana Explorer',
        url: 'https://zkatana.explorer.startale.com',
      },
    },
    iconUrl: '/static/images/chainIcons/astar.ico',
    testnet: true,
  },
};

window.appConfig = {
  env,
  integrations,
  ui,
  customChains,
  defaultWagmiChains,
};
